@@ -1,9 +1,10 @@
 
-# $rcs = ' $Id: Search.pm,v 1.7 2007/07/22 12:20:35 Daddy Exp $ ' ;
+# $rcs = ' $Id: Search.pm,v 1.9 2010/03/06 13:33:22 Martin Exp $ ' ;
 
 package WWW::Ebay::Search;
 
 use strict;
+use warnings;
 
 use WWW::Search::Ebay;
 
@@ -16,5 +17,8 @@ __END__
 
 =head1 AUTHOR
 
-Martin Thurn, C<mthurn@cpan.org>, L<http://www.sandcrawler.com/SWB/cpan-modules.html>.
+Martin 'Kingpin' Thurn, C<mthurn at cpan.org>, L<http://tinyurl.com/nn67z>.
+
+=cut
+
 
